/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison implementation for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.5"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Push parsers.  */
#define YYPUSH 1

/* Pull parsers.  */
#define YYPULL 0

/* Using locations.  */
#define YYLSP_NEEDED 1

/* Substitute the variable and function names.  */
#define yypush_parse    amp_ac_yypush_parse
#define yypstate_new    amp_ac_yypstate_new
#define yypstate_delete amp_ac_yypstate_delete
#define yypstate        amp_ac_yypstate
#define yylex           amp_ac_yylex
#define yyerror         amp_ac_yyerror
#define yylval          amp_ac_yylval
#define yychar          amp_ac_yychar
#define yydebug         amp_ac_yydebug
#define yynerrs         amp_ac_yynerrs
#define yylloc          amp_ac_yylloc

/* Copy the first part of user declarations.  */

/* Line 268 of yacc.c  */
#line 19 "ac-parser.y"


#include "ac-scanner.h"
#include "ac-parser.h"

#include <stdlib.h>

//#define YYDEBUG 1

#include "libanjuta/anjuta-debug.h"

/* Token location is found directly from token value, there is no need to
 * maintain a separate location variable */
#define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))


/* Line 268 of yacc.c  */
#line 127 "ac-parser.y"


static gint
amp_ac_autoconf_macro (AnjutaToken *token)
{
    switch (anjuta_token_get_type (token))
    {
	case AC_ARG_ENABLE:			return AC_TOKEN_AC_ARG_ENABLE;
	case AC_C_CONST:			return AC_TOKEN_AC_C_CONST;
	case AC_CHECK_FUNCS:		return AC_TOKEN_AC_CHECK_FUNCS;
	case AC_CHECK_HEADERS:		return AC_TOKEN_AC_CHECK_HEADERS;
	case AC_CHECK_LIB:			return AC_TOKEN_AC_CHECK_LIB;
	case AC_CHECK_PROG:			return AC_TOKEN_AC_CHECK_PROG;
	case AC_CONFIG_FILES:		return AC_TOKEN_AC_CONFIG_FILES;
	case AC_CONFIG_HEADERS:		return AC_TOKEN_AC_CONFIG_HEADERS;
	case AC_CONFIG_MACRO_DIR:	return AC_TOKEN_AC_CONFIG_MACRO_DIR;
	case AC_CONFIG_SRCDIR:		return AC_TOKEN_AC_CONFIG_SRCDIR;
	case AC_EGREP_HEADER:		return AC_TOKEN_AC_EGREP_HEADER;
	case AC_EXEEXT:				return AC_TOKEN_AC_EXEEXT;
	case AC_HEADER_STDC:		return AC_TOKEN_AC_HEADER_STDC;
	case AC_INIT:				return AC_TOKEN_AC_INIT;
	case AC_OBJEXT:				return AC_TOKEN_AC_OBJEXT;
	case AC_OUTPUT:				return AC_TOKEN_AC_OUTPUT;
	case OBSOLETE_AC_OUTPUT:	return AC_TOKEN_OBSOLETE_AC_OUTPUT;
	case AC_PREREQ:				return AC_TOKEN_AC_PREREQ;
	case AC_PROG_CC:			return AC_TOKEN_AC_PROG_CC;
	case AC_PROG_CPP:			return AC_TOKEN_AC_PROG_CPP;
	case AC_PROG_CXX:			return AC_TOKEN_AC_PROG_CXX;
	case IT_PROG_INTLTOOL:		return AC_TOKEN_IT_PROG_INTLTOOL;
	case AC_PROG_LEX:			return AC_TOKEN_AC_PROG_LEX;
	case AC_PROG_RANLIB:		return AC_TOKEN_AC_PROG_RANLIB;
	case AC_PROG_YACC:			return AC_TOKEN_AC_PROG_YACC;
	case AC_TYPE_SIZE_T:		return AC_TOKEN_AC_TYPE_SIZE_T;
	case AC_TYPE_OFF_T:			return AC_TOKEN_AC_TYPE_OFF_T;
	case AM_INIT_AUTOMAKE:		return AC_TOKEN_AM_INIT_AUTOMAKE;
	case AM_GLIB_GNU_GETTEXT:	return AC_TOKEN_AM_GLIB_GNU_GETTEXT;
	case AM_MAINTAINER_MODE:	return AC_TOKEN_AM_MAINTAINER_MODE;
	case AM_PROG_LIBTOOL:		return AC_TOKEN_AM_PROG_LIBTOOL;
	case LT_INIT:				return AC_TOKEN_LT_INIT;
	case LT_PREREQ:				return AC_TOKEN_LT_PREREQ;
	case PKG_CHECK_MODULES:		return AC_TOKEN_PKG_CHECK_MODULES;
	case PKG_PROG_PKG_CONFIG:	return AC_TOKEN_PKG_PROG_PKG_CONFIG;
    default: return anjuta_token_get_type (token);
    }
}



/* Line 268 of yacc.c  */
#line 149 "ac-parser.c"

/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 1
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EOL = 259,
     SPACE = 260,
     HASH = 261,
     LEFT_PAREN = 262,
     RIGHT_PAREN = 263,
     LEFT_CURLY = 264,
     RIGHT_CURLY = 265,
     LEFT_BRACE = 266,
     RIGHT_BRACE = 267,
     EQUAL = 268,
     COMMA = 269,
     LOWER = 270,
     GREATER = 271,
     COMMENT = 256,
     NAME = 272,
     VARIABLE = 273,
     MACRO = 274,
     OPERATOR = 275,
     WORD = 276,
     JUNK = 277,
     START_SPACE_LIST = 278,
     DNL = 279,
     AC_MACRO_WITH_ARG = 280,
     AC_MACRO_WITHOUT_ARG = 281,
     AC_ARG_ENABLE = 282,
     AC_C_CONST = 283,
     AC_CHECK_FUNCS = 284,
     AC_CHECK_HEADERS = 285,
     AC_CHECK_LIB = 286,
     AC_CHECK_PROG = 287,
     AC_CONFIG_FILES = 288,
     AC_CONFIG_HEADERS = 289,
     AC_CONFIG_MACRO_DIR = 290,
     AC_CONFIG_SRCDIR = 291,
     AC_EGREP_HEADER = 292,
     AC_EXEEXT = 293,
     AC_HEADER_STDC = 294,
     AC_INIT = 295,
     AC_OBJEXT = 296,
     AC_OUTPUT = 297,
     OBSOLETE_AC_OUTPUT = 298,
     AC_PREREQ = 299,
     AC_PROG_CC = 300,
     AC_PROG_CPP = 301,
     AC_PROG_CXX = 302,
     IT_PROG_INTLTOOL = 303,
     AC_PROG_LEX = 304,
     AC_PROG_RANLIB = 305,
     AC_PROG_YACC = 306,
     AC_SUBST = 307,
     AC_TYPE_SIZE_T = 308,
     AC_TYPE_OFF_T = 309,
     AM_INIT_AUTOMAKE = 310,
     AM_GLIB_GNU_GETTEXT = 311,
     AM_MAINTAINER_MODE = 312,
     AM_PROG_LIBTOOL = 313,
     LT_INIT = 314,
     LT_PREREQ = 315,
     PKG_CHECK_MODULES = 316,
     PKG_PROG_PKG_CONFIG = 317,
     EMPTY = 318,
     ARG = 319
   };
#endif
/* Tokens.  */
#define EOL 259
#define SPACE 260
#define HASH 261
#define LEFT_PAREN 262
#define RIGHT_PAREN 263
#define LEFT_CURLY 264
#define RIGHT_CURLY 265
#define LEFT_BRACE 266
#define RIGHT_BRACE 267
#define EQUAL 268
#define COMMA 269
#define LOWER 270
#define GREATER 271
#define COMMENT 256
#define NAME 272
#define VARIABLE 273
#define MACRO 274
#define OPERATOR 275
#define WORD 276
#define JUNK 277
#define START_SPACE_LIST 278
#define DNL 279
#define AC_MACRO_WITH_ARG 280
#define AC_MACRO_WITHOUT_ARG 281
#define AC_ARG_ENABLE 282
#define AC_C_CONST 283
#define AC_CHECK_FUNCS 284
#define AC_CHECK_HEADERS 285
#define AC_CHECK_LIB 286
#define AC_CHECK_PROG 287
#define AC_CONFIG_FILES 288
#define AC_CONFIG_HEADERS 289
#define AC_CONFIG_MACRO_DIR 290
#define AC_CONFIG_SRCDIR 291
#define AC_EGREP_HEADER 292
#define AC_EXEEXT 293
#define AC_HEADER_STDC 294
#define AC_INIT 295
#define AC_OBJEXT 296
#define AC_OUTPUT 297
#define OBSOLETE_AC_OUTPUT 298
#define AC_PREREQ 299
#define AC_PROG_CC 300
#define AC_PROG_CPP 301
#define AC_PROG_CXX 302
#define IT_PROG_INTLTOOL 303
#define AC_PROG_LEX 304
#define AC_PROG_RANLIB 305
#define AC_PROG_YACC 306
#define AC_SUBST 307
#define AC_TYPE_SIZE_T 308
#define AC_TYPE_OFF_T 309
#define AM_INIT_AUTOMAKE 310
#define AM_GLIB_GNU_GETTEXT 311
#define AM_MAINTAINER_MODE 312
#define AM_PROG_LIBTOOL 313
#define LT_INIT 314
#define LT_PREREQ 315
#define PKG_CHECK_MODULES 316
#define PKG_PROG_PKG_CONFIG 317
#define EMPTY 318
#define ARG 319




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

#ifndef YYPUSH_DECLS
#  define YYPUSH_DECLS
struct yypstate;
typedef struct yypstate yypstate;
enum { YYPUSH_MORE = 4 };

#if defined __STDC__ || defined __cplusplus
int yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAcScanner* scanner);
#else
int yypush_parse ();
#endif

#if defined __STDC__ || defined __cplusplus
yypstate * yypstate_new (void);
#else
yypstate * yypstate_new ();
#endif
#if defined __STDC__ || defined __cplusplus
void yypstate_delete (yypstate *yyps);
#else
void yypstate_delete ();
#endif
#endif


/* Copy the second part of user declarations.  */


/* Line 343 of yacc.c  */
#line 356 "ac-parser.c"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(e) ((void) (e))
#else
# define YYUSE(e) /* empty */
#endif

/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(n) (n)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int yyi)
#else
static int
YYID (yyi)
    int yyi;
#endif
{
  return yyi;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL \
	     && defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
  YYLTYPE yyls_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE) + sizeof (YYLTYPE)) \
      + 2 * YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
	Stack = &yyptr->Stack_alloc;					\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T yyi;				\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (YYID (0))
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  66
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   986

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  78
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  47
/* YYNRULES -- Number of rules.  */
#define YYNRULES  192
/* YYNRULES -- Number of states.  */
#define YYNSTATES  209

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   319

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       4,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     6,     2,     2,     8,     2,     2,     2,     2,
      10,    12,     2,     2,    24,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      26,    22,    28,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    18,     2,    20,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    14,     2,    16,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,    29,     1,     2,     3,
       5,     7,     9,    11,    13,    15,    17,    19,    21,    23,
      25,    27,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
      58,    59,    60,    61,    62,    63,    64,    65,    66,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     5,     8,     9,    12,    14,    16,    18,
      20,    22,    24,    26,    28,    30,    32,    34,    36,    38,
      40,    42,    44,    46,    48,    50,    52,    53,    55,    58,
      60,    63,    67,    69,    71,    73,    75,    78,    82,    85,
      88,    90,    93,    95,    98,   101,   104,   108,   110,   114,
     118,   119,   122,   126,   127,   130,   133,   137,   138,   141,
     144,   148,   149,   152,   155,   158,   161,   164,   167,   170,
     173,   176,   179,   182,   185,   188,   189,   192,   193,   196,
     198,   200,   202,   204,   206,   208,   210,   212,   214,   216,
     218,   220,   222,   224,   227,   231,   232,   235,   238,   241,
     244,   247,   250,   253,   256,   259,   262,   265,   268,   270,
     273,   275,   277,   279,   281,   283,   285,   287,   289,   291,
     293,   295,   297,   299,   301,   303,   305,   307,   309,   311,
     313,   315,   317,   319,   321,   323,   325,   327,   329,   331,
     333,   335,   337,   339,   341,   343,   345,   347,   349,   351,
     353,   355,   357,   359,   361,   363,   365,   367,   369,   371,
     373,   375,   377,   379,   381,   383,   385,   387,   389,   391,
     393,   395,   397,   399,   401,   403,   405,   407,   409,   411,
     413,   415,   417,   419,   421,   423,   425,   427,   429,   431,
     433,   435,   437
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int8 yyrhs[] =
{
      79,     0,    -1,    80,    -1,    36,    84,    -1,    -1,    80,
      81,    -1,    82,    -1,    83,    -1,   118,    -1,    99,    -1,
     101,    -1,   119,    -1,    21,    -1,    25,    -1,    27,    -1,
      30,    -1,    31,    -1,    34,    -1,    89,    -1,    91,    -1,
      92,    -1,    93,    -1,    90,    -1,    95,    -1,    94,    -1,
      96,    -1,    -1,    85,    -1,    85,   115,    -1,    86,    -1,
     115,    86,    -1,    85,   115,    86,    -1,    88,    -1,    87,
      -1,    33,    -1,   120,    -1,    88,   121,    -1,    37,   100,
       3,    -1,    74,    97,    -1,   124,    97,    -1,   123,    -1,
      53,    97,    -1,    55,    -1,    56,    97,    -1,    46,    97,
      -1,    98,    11,    -1,   115,    98,    11,    -1,   107,    -1,
      98,   112,   107,    -1,     7,   100,     3,    -1,    -1,   100,
     116,    -1,    17,   102,    19,    -1,    -1,   102,   117,    -1,
     102,   101,    -1,    17,   104,    19,    -1,    -1,   104,   117,
      -1,   104,   103,    -1,    17,   106,    19,    -1,    -1,   106,
     118,    -1,   106,     7,    -1,   106,     9,    -1,   106,    11,
      -1,   106,    23,    -1,   106,    21,    -1,   106,    27,    -1,
     106,    25,    -1,   106,    30,    -1,   106,    31,    -1,   106,
      34,    -1,   106,    83,    -1,   106,   103,    -1,    -1,   110,
     108,    -1,    -1,   108,   109,    -1,   118,    -1,   110,    -1,
     105,    -1,   113,    -1,    83,    -1,   111,    -1,     7,    -1,
      21,    -1,    25,    -1,    27,    -1,    30,    -1,    31,    -1,
      34,    -1,    23,    -1,    23,   115,    -1,     9,   114,    11,
      -1,    -1,   114,   118,    -1,   114,    99,    -1,   114,    23,
      -1,   114,    21,    -1,   114,    25,    -1,   114,    27,    -1,
     114,    30,    -1,   114,    31,    -1,   114,    34,    -1,   114,
      83,    -1,   114,   113,    -1,   114,   105,    -1,   118,    -1,
     115,   118,    -1,     5,    -1,   121,    -1,   118,    -1,   119,
      -1,     7,    -1,    21,    -1,    25,    -1,    27,    -1,    33,
      -1,    30,    -1,    31,    -1,    34,    -1,   122,    -1,     5,
      -1,     3,    -1,     9,    -1,    11,    -1,    23,    -1,     7,
      -1,    17,    -1,    19,    -1,     9,    -1,    11,    -1,    23,
      -1,    30,    -1,    31,    -1,    34,    -1,   122,    -1,     7,
      -1,    17,    -1,    19,    -1,     9,    -1,    11,    -1,    23,
      -1,    33,    -1,    21,    -1,    25,    -1,    27,    -1,    30,
      -1,    31,    -1,    34,    -1,   122,    -1,    46,    -1,    55,
      -1,    37,    -1,    56,    -1,    74,    -1,    53,    -1,   124,
      -1,   123,    -1,    39,    -1,    41,    -1,    51,    -1,    52,
      -1,    54,    -1,    58,    -1,    59,    -1,    60,    -1,    62,
      -1,    63,    -1,    64,    -1,    66,    -1,    67,    -1,    70,
      -1,    71,    -1,    38,    -1,    40,    -1,    42,    -1,    43,
      -1,    44,    -1,    45,    -1,    47,    -1,    48,    -1,    49,
      -1,    50,    -1,    57,    -1,    61,    -1,    65,    -1,    68,
      -1,    69,    -1,    72,    -1,    73,    -1,    75,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   178,   178,   179,   182,   184,   188,   189,   193,   194,
     195,   196,   197,   198,   199,   200,   201,   202,   206,   207,
     208,   209,   210,   211,   212,   213,   219,   221,   222,   228,
     229,   232,   238,   239,   243,   249,   253,   262,   272,   286,
     294,   299,   307,   313,   322,   334,   340,   352,   358,   373,
     382,   385,   392,   401,   404,   407,   413,   422,   425,   428,
     434,   443,   446,   449,   452,   455,   458,   461,   464,   467,
     470,   473,   476,   479,   480,   489,   492,   504,   507,   513,
     517,   521,   522,   523,   524,   531,   532,   533,   534,   535,
     536,   537,   541,   545,   561,   568,   571,   574,   575,   578,
     581,   584,   587,   590,   593,   596,   597,   600,   606,   610,
     619,   620,   624,   625,   626,   627,   628,   629,   630,   631,
     632,   633,   634,   638,   639,   645,   646,   647,   651,   652,
     653,   654,   655,   656,   657,   658,   659,   660,   664,   665,
     666,   667,   668,   669,   670,   671,   672,   673,   674,   675,
     676,   677,   681,   682,   683,   684,   685,   686,   687,   688,
     692,   693,   694,   695,   696,   697,   698,   699,   700,   701,
     702,   703,   704,   705,   706,   710,   711,   712,   713,   714,
     715,   716,   717,   718,   719,   720,   721,   722,   723,   724,
     725,   726,   727
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "EOL", "'\\n'", "SPACE", "' '", "HASH",
  "'#'", "LEFT_PAREN", "'('", "RIGHT_PAREN", "')'", "LEFT_CURLY", "'{'",
  "RIGHT_CURLY", "'}'", "LEFT_BRACE", "'['", "RIGHT_BRACE", "']'", "EQUAL",
  "'='", "COMMA", "','", "LOWER", "'<'", "GREATER", "'>'", "COMMENT",
  "NAME", "VARIABLE", "MACRO", "OPERATOR", "WORD", "JUNK",
  "START_SPACE_LIST", "DNL", "AC_MACRO_WITH_ARG", "AC_MACRO_WITHOUT_ARG",
  "AC_ARG_ENABLE", "AC_C_CONST", "AC_CHECK_FUNCS", "AC_CHECK_HEADERS",
  "AC_CHECK_LIB", "AC_CHECK_PROG", "AC_CONFIG_FILES", "AC_CONFIG_HEADERS",
  "AC_CONFIG_MACRO_DIR", "AC_CONFIG_SRCDIR", "AC_EGREP_HEADER",
  "AC_EXEEXT", "AC_HEADER_STDC", "AC_INIT", "AC_OBJEXT", "AC_OUTPUT",
  "OBSOLETE_AC_OUTPUT", "AC_PREREQ", "AC_PROG_CC", "AC_PROG_CPP",
  "AC_PROG_CXX", "IT_PROG_INTLTOOL", "AC_PROG_LEX", "AC_PROG_RANLIB",
  "AC_PROG_YACC", "AC_SUBST", "AC_TYPE_SIZE_T", "AC_TYPE_OFF_T",
  "AM_INIT_AUTOMAKE", "AM_GLIB_GNU_GETTEXT", "AM_MAINTAINER_MODE",
  "AM_PROG_LIBTOOL", "LT_INIT", "LT_PREREQ", "PKG_CHECK_MODULES",
  "PKG_PROG_PKG_CONFIG", "EMPTY", "ARG", "$accept", "input", "file",
  "statement", "line", "macro", "space_list", "space_list_body", "item",
  "operator", "name", "dnl", "pkg_check_modules", "ac_macro_with_arg",
  "ac_macro_without_arg", "ac_init", "ac_output", "obsolete_ac_output",
  "ac_config_files", "arg_list", "arg_list_body", "comment",
  "not_eol_list", "shell_string", "shell_string_body", "raw_string",
  "raw_string_body", "arg_string", "arg_string_body", "arg", "arg_body",
  "arg_part_or_space", "arg_part", "arg_token", "separator", "expression",
  "expression_body", "spaces", "not_eol_token", "not_brace_token",
  "space_token", "args_token", "not_operator_token", "word_token",
  "any_macro", "ac_macro_without_arg_token", "ac_macro_with_arg_token", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   257,   258,   259,    10,   260,    32,   261,    35,   262,
      40,   263,    41,   264,   123,   265,   125,   266,    91,   267,
      93,   268,    61,   269,    44,   270,    60,   271,    62,   256,
     272,   273,   274,   275,   276,   277,   278,   279,   280,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   299,   300,   301,
     302,   303,   304,   305,   306,   307,   308,   309,   310,   311,
     312,   313,   314,   315,   316,   317,   318,   319
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    78,    79,    79,    80,    80,    81,    81,    82,    82,
      82,    82,    82,    82,    82,    82,    82,    82,    83,    83,
      83,    83,    83,    83,    83,    83,    84,    84,    84,    85,
      85,    85,    86,    86,    87,    88,    88,    89,    90,    91,
      92,    93,    94,    95,    96,    97,    97,    98,    98,    99,
     100,   100,   101,   102,   102,   102,   103,   104,   104,   104,
     105,   106,   106,   106,   106,   106,   106,   106,   106,   106,
     106,   106,   106,   106,   106,   107,   107,   108,   108,   109,
     109,   110,   110,   110,   110,   111,   111,   111,   111,   111,
     111,   111,   112,   112,   113,   114,   114,   114,   114,   114,
     114,   114,   114,   114,   114,   114,   114,   114,   115,   115,
     116,   116,   117,   117,   117,   117,   117,   117,   117,   117,
     117,   117,   117,   118,   118,   119,   119,   119,   120,   120,
     120,   120,   120,   120,   120,   120,   120,   120,   121,   121,
     121,   121,   121,   121,   121,   121,   121,   121,   121,   121,
     121,   121,   122,   122,   122,   122,   122,   122,   122,   122,
     123,   123,   123,   123,   123,   123,   123,   123,   123,   123,
     123,   123,   123,   123,   123,   124,   124,   124,   124,   124,
     124,   124,   124,   124,   124,   124,   124,   124,   124,   124,
     124,   124,   124
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     1,     2,     0,     2,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     0,     1,     2,     1,
       2,     3,     1,     1,     1,     1,     2,     3,     2,     2,
       1,     2,     1,     2,     2,     2,     3,     1,     3,     3,
       0,     2,     3,     0,     2,     2,     3,     0,     2,     2,
       3,     0,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     0,     2,     0,     2,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     2,     3,     0,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     1,     2,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1
};

/* YYDEFACT[STATE-NAME] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       4,    26,     0,     2,   124,   123,   128,   131,   132,   129,
     130,   133,   134,   135,    34,   136,   154,   175,   160,   176,
     161,   177,   178,   179,   180,   152,   181,   182,   183,   184,
     162,   163,   157,   164,   153,   155,   185,   165,   166,   167,
     186,   168,   169,   170,   187,   171,   172,   188,   189,   173,
     174,   190,   191,   156,   192,     3,    27,    29,    33,    32,
       0,   108,    35,   137,   159,   158,     1,    50,   125,   126,
      53,    12,   127,    13,    14,    15,    16,    17,    50,    75,
      75,    42,    75,    75,     5,     6,     7,    18,    22,    19,
      20,    21,    24,    23,    25,     9,    10,     8,    11,    40,
      75,    28,   138,   141,   142,   139,   140,   145,   143,   146,
     147,   148,   149,   144,   150,    36,   151,    30,   109,     0,
       0,     0,    85,    95,    61,    86,    87,    88,    89,    90,
      91,    83,    44,     0,    81,    47,    77,    84,    82,    75,
      41,    43,    38,    39,    31,    49,   110,    51,   111,   114,
      52,   115,   116,   117,   119,   120,   118,   121,    55,    54,
     112,   113,   122,    37,     0,     0,    45,    92,    75,    76,
       0,    94,    99,    98,   100,   101,   102,   103,   104,   105,
      97,   107,   106,    96,    63,    64,    65,    57,    60,    67,
      66,    69,    68,    70,    71,    72,    73,    74,    62,    93,
      48,    78,    80,    79,    46,     0,    56,    59,    58
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,     2,     3,    84,    85,   131,    55,    56,    57,    58,
      59,    87,    88,    89,    90,    91,    92,    93,    94,   132,
     133,    95,   119,    96,   120,   197,   205,   134,   165,   135,
     169,   201,   136,   137,   168,   138,   164,   139,   147,   159,
      61,   161,    62,   148,    63,    99,   100
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -186
static const yytype_int16 yypact[] =
{
     -25,   700,    13,   554,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,     7,  -186,  -186,   842,
     700,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,   773,
     773,  -186,   773,   773,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
     773,   700,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,   189,
     262,   335,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,     5,  -186,  -186,  -186,  -186,  -186,   773,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,   627,   481,  -186,     7,   911,   773,
       6,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,     7,
    -186,  -186,  -186,  -186,  -186,   408,  -186,  -186,  -186
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -186,  -186,  -186,  -186,  -186,     1,  -186,  -186,   -58,  -186,
    -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,  -186,   -74,
    -125,  -149,   -60,  -101,  -186,  -185,  -186,  -143,  -186,  -146,
    -186,  -186,  -145,  -186,  -186,  -141,  -186,     0,  -186,  -180,
       4,    24,  -186,   -29,   -54,    -1,     2
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const yytype_uint8 yytable[] =
{
      64,    60,   117,    65,    86,   116,   140,    97,   141,   142,
       4,     1,     5,    66,   170,   180,   166,   204,   121,   158,
     207,   181,   200,   182,   202,   208,   143,    98,   167,   167,
     115,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   144,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   101,     0,    64,    64,
       0,    65,    65,     0,   118,   116,   162,   116,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      64,     0,     0,    65,     0,   118,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    64,    64,
      64,    65,    65,    65,   160,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   118,     0,     0,     0,     0,     0,     0,
       0,   162,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   179,   196,   199,   183,   198,
       0,     0,     0,   203,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   145,     0,   146,     0,   102,     0,   103,     0,
     104,     0,     0,   118,    64,     0,   105,    65,   106,   160,
     107,     0,   108,     0,   109,     0,   110,     0,     0,   111,
     112,     0,   113,   114,     0,     0,    16,    17,    18,    19,
      20,    21,    22,    23,    24,    25,    26,    27,    28,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    48,    49,
      50,    51,    52,    53,    54,     4,     0,     5,     0,   149,
       0,    68,     0,    69,     0,     0,     0,     0,     0,    70,
       0,   150,     0,   151,     0,    72,     0,   152,     0,   153,
       0,     0,   154,   155,     0,   156,   157,     0,     0,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,   163,     0,
     146,     0,   102,     0,   103,     0,   104,     0,     0,     0,
       0,     0,   105,     0,   106,     0,   107,     0,   108,     0,
     109,     0,   110,     0,     0,   111,   112,     0,   113,   114,
       0,     0,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    48,    49,    50,    51,    52,    53,
      54,     4,     0,     5,     0,   149,     0,    68,     0,    69,
       0,     0,     0,     0,     0,   187,     0,   206,     0,   151,
       0,    72,     0,   152,     0,   153,     0,     0,   154,   155,
       0,   156,   157,     0,     0,    16,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,     4,     0,     5,     0,   184,     0,
     185,     0,   186,     0,     0,     0,     0,     0,   187,     0,
     188,     0,   189,     0,   190,     0,   191,     0,   192,     0,
       0,   193,   194,     0,     0,   195,     0,     0,    78,    17,
      18,    19,    20,    21,    22,    23,    24,    79,    26,    27,
      28,    29,    30,    31,    80,    33,    81,    82,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    83,    54,     4,     0,     5,
       0,    67,     0,    68,     0,    69,     0,     0,     0,     0,
       0,    70,     0,     0,     0,    71,     0,    72,     0,    73,
       0,    74,     0,     0,    75,    76,     0,     0,    77,     0,
       0,    78,    17,    18,    19,    20,    21,    22,    23,    24,
      79,    26,    27,    28,    29,    30,    31,    80,    33,    81,
      82,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    83,    54,
       4,     0,     5,     0,    67,     0,   123,     0,   171,     0,
       0,     0,     0,     0,   124,     0,     0,     0,   172,     0,
     173,     0,   174,     0,   175,     0,     0,   176,   177,     0,
       0,   178,     0,     0,    78,    17,    18,    19,    20,    21,
      22,    23,    24,    79,    26,    27,    28,    29,    30,    31,
      80,    33,    81,    82,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    48,    49,    50,    51,
      52,    83,    54,     4,     0,     5,     0,     6,     0,     7,
       0,     8,     0,     0,     0,     0,     0,     9,     0,    10,
       0,     0,     0,    11,     0,     0,     0,     0,     0,     0,
      12,    13,     0,    14,    15,     0,     0,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,     4,     0,     5,     0,
     122,     0,   123,     0,     0,     0,     0,     0,     0,     0,
     124,     0,     0,     0,   125,     0,     0,     0,   126,     0,
     127,     0,     0,   128,   129,     0,     0,   130,     0,     0,
      78,    17,    18,    19,    20,    21,    22,    23,    24,    79,
      26,    27,    28,    29,    30,    31,    80,    33,    81,    82,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    83,    54,   102,
       0,   103,     0,   104,     0,     0,     0,     0,     0,   105,
       0,   106,     0,   107,     0,   108,     0,   109,     0,   110,
       0,     0,   111,   112,     0,   113,   114,     0,     0,    16,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,   122,     0,
     123,     0,     0,     0,     0,     0,     0,     0,   124,     0,
       0,     0,   125,     0,     0,     0,   126,     0,   127,     0,
       0,   128,   129,     0,     0,   130,     0,     0,    78,    17,
      18,    19,    20,    21,    22,    23,    24,    79,    26,    27,
      28,    29,    30,    31,    80,    33,    81,    82,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    83,    54
};

#define yypact_value_is_default(yystate) \
  ((yystate) == (-186))

#define yytable_value_is_error(yytable_value) \
  YYID (0)

static const yytype_int16 yycheck[] =
{
       1,     1,    60,     1,     3,    59,    80,     3,    82,    83,
       3,    36,     5,     0,   139,   164,    11,    11,    78,   120,
     205,   164,   168,   164,   169,   205,   100,     3,    23,    23,
      59,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   101,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    56,    -1,    59,    60,
      -1,    59,    60,    -1,    60,   119,   120,   121,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
     101,    -1,    -1,   101,    -1,   101,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   119,   120,
     121,   119,   120,   121,   120,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   139,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   205,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,   164,   165,   167,   164,   165,
      -1,    -1,    -1,   169,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,     3,    -1,     5,    -1,     7,    -1,     9,    -1,
      11,    -1,    -1,   199,   205,    -1,    17,   205,    19,   205,
      21,    -1,    23,    -1,    25,    -1,    27,    -1,    -1,    30,
      31,    -1,    33,    34,    -1,    -1,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
      61,    62,    63,    64,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,     3,    -1,     5,    -1,     7,
      -1,     9,    -1,    11,    -1,    -1,    -1,    -1,    -1,    17,
      -1,    19,    -1,    21,    -1,    23,    -1,    25,    -1,    27,
      -1,    -1,    30,    31,    -1,    33,    34,    -1,    -1,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
      58,    59,    60,    61,    62,    63,    64,    65,    66,    67,
      68,    69,    70,    71,    72,    73,    74,    75,     3,    -1,
       5,    -1,     7,    -1,     9,    -1,    11,    -1,    -1,    -1,
      -1,    -1,    17,    -1,    19,    -1,    21,    -1,    23,    -1,
      25,    -1,    27,    -1,    -1,    30,    31,    -1,    33,    34,
      -1,    -1,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,     3,    -1,     5,    -1,     7,    -1,     9,    -1,    11,
      -1,    -1,    -1,    -1,    -1,    17,    -1,    19,    -1,    21,
      -1,    23,    -1,    25,    -1,    27,    -1,    -1,    30,    31,
      -1,    33,    34,    -1,    -1,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,    58,    59,    60,    61,
      62,    63,    64,    65,    66,    67,    68,    69,    70,    71,
      72,    73,    74,    75,     3,    -1,     5,    -1,     7,    -1,
       9,    -1,    11,    -1,    -1,    -1,    -1,    -1,    17,    -1,
      19,    -1,    21,    -1,    23,    -1,    25,    -1,    27,    -1,
      -1,    30,    31,    -1,    -1,    34,    -1,    -1,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,    58,
      59,    60,    61,    62,    63,    64,    65,    66,    67,    68,
      69,    70,    71,    72,    73,    74,    75,     3,    -1,     5,
      -1,     7,    -1,     9,    -1,    11,    -1,    -1,    -1,    -1,
      -1,    17,    -1,    -1,    -1,    21,    -1,    23,    -1,    25,
      -1,    27,    -1,    -1,    30,    31,    -1,    -1,    34,    -1,
      -1,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,    58,    59,    60,    61,    62,    63,    64,    65,
      66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
       3,    -1,     5,    -1,     7,    -1,     9,    -1,    11,    -1,
      -1,    -1,    -1,    -1,    17,    -1,    -1,    -1,    21,    -1,
      23,    -1,    25,    -1,    27,    -1,    -1,    30,    31,    -1,
      -1,    34,    -1,    -1,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,    48,    49,    50,    51,    52,
      53,    54,    55,    56,    57,    58,    59,    60,    61,    62,
      63,    64,    65,    66,    67,    68,    69,    70,    71,    72,
      73,    74,    75,     3,    -1,     5,    -1,     7,    -1,     9,
      -1,    11,    -1,    -1,    -1,    -1,    -1,    17,    -1,    19,
      -1,    -1,    -1,    23,    -1,    -1,    -1,    -1,    -1,    -1,
      30,    31,    -1,    33,    34,    -1,    -1,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    48,    49,
      50,    51,    52,    53,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    66,    67,    68,    69,
      70,    71,    72,    73,    74,    75,     3,    -1,     5,    -1,
       7,    -1,     9,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      17,    -1,    -1,    -1,    21,    -1,    -1,    -1,    25,    -1,
      27,    -1,    -1,    30,    31,    -1,    -1,    34,    -1,    -1,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    66,
      67,    68,    69,    70,    71,    72,    73,    74,    75,     7,
      -1,     9,    -1,    11,    -1,    -1,    -1,    -1,    -1,    17,
      -1,    19,    -1,    21,    -1,    23,    -1,    25,    -1,    27,
      -1,    -1,    30,    31,    -1,    33,    34,    -1,    -1,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
      58,    59,    60,    61,    62,    63,    64,    65,    66,    67,
      68,    69,    70,    71,    72,    73,    74,    75,     7,    -1,
       9,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    17,    -1,
      -1,    -1,    21,    -1,    -1,    -1,    25,    -1,    27,    -1,
      -1,    30,    31,    -1,    -1,    34,    -1,    -1,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,    58,
      59,    60,    61,    62,    63,    64,    65,    66,    67,    68,
      69,    70,    71,    72,    73,    74,    75
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    36,    79,    80,     3,     5,     7,     9,    11,    17,
      19,    23,    30,    31,    33,    34,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
      61,    62,    63,    64,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    84,    85,    86,    87,    88,
     115,   118,   120,   122,   123,   124,     0,     7,     9,    11,
      17,    21,    23,    25,    27,    30,    31,    34,    37,    46,
      53,    55,    56,    74,    81,    82,    83,    89,    90,    91,
      92,    93,    94,    95,    96,    99,   101,   118,   119,   123,
     124,   115,     7,     9,    11,    17,    19,    21,    23,    25,
      27,    30,    31,    33,    34,   121,   122,    86,   118,   100,
     102,   100,     7,     9,    17,    21,    25,    27,    30,    31,
      34,    83,    97,    98,   105,   107,   110,   111,   113,   115,
      97,    97,    97,    97,    86,     3,     5,   116,   121,     7,
      19,    21,    25,    27,    30,    31,    33,    34,   101,   117,
     118,   119,   122,     3,   114,   106,    11,    23,   112,   108,
      98,    11,    21,    23,    25,    27,    30,    31,    34,    83,
      99,   105,   113,   118,     7,     9,    11,    17,    19,    21,
      23,    25,    27,    30,    31,    34,    83,   103,   118,   115,
     107,   109,   110,   118,    11,   104,    19,   103,   117
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  However,
   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
   discussed.  */

#define YYFAIL		goto yyerrlab
#if defined YYFAIL
  /* This is here to suppress warnings from the GCC cpp's
     -Wunused-macros.  Normally we don't worry about that warning, but
     some users do, and we want to make it easy for users to remove
     YYFAIL uses, which will produce warnings from Bison 2.5.  */
#endif

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      YYPOPSTACK (1);						\
      goto yybackup;						\
    }								\
  else								\
    {								\
      yyerror (&yylloc, scanner, YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (YYID (N))                                                    \
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (YYID (0))
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
	      (Loc).first_line, (Loc).first_column,	\
	      (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (&yylval, &yylloc, YYLEX_PARAM)
#else
# define YYLEX yylex (&yylval, &yylloc, scanner)
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value, Location, scanner); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp, AmpAcScanner* scanner)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp, scanner)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
    YYLTYPE const * const yylocationp;
    AmpAcScanner* scanner;
#endif
{
  if (!yyvaluep)
    return;
  YYUSE (yylocationp);
  YYUSE (scanner);
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  switch (yytype)
    {
      default:
	break;
    }
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, YYLTYPE const * const yylocationp, AmpAcScanner* scanner)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep, yylocationp, scanner)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
    YYLTYPE const * const yylocationp;
    AmpAcScanner* scanner;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  YY_LOCATION_PRINT (yyoutput, *yylocationp);
  YYFPRINTF (yyoutput, ": ");
  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp, scanner);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
#else
static void
yy_stack_print (yybottom, yytop)
    yytype_int16 *yybottom;
    yytype_int16 *yytop;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, YYLTYPE *yylsp, int yyrule, AmpAcScanner* scanner)
#else
static void
yy_reduce_print (yyvsp, yylsp, yyrule, scanner)
    YYSTYPE *yyvsp;
    YYLTYPE *yylsp;
    int yyrule;
    AmpAcScanner* scanner;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       , &(yylsp[(yyi + 1) - (yynrhs)])		       , scanner);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, yylsp, Rule, scanner); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  YYSIZE_T yysize1;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = 0;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - Assume YYFAIL is not used.  It's too flawed to consider.  See
       <http://lists.gnu.org/archive/html/bison-patches/2009-12/msg00024.html>
       for details.  YYERROR is fine as it does not invoke this
       function.
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                yysize1 = yysize + yytnamerr (0, yytname[yyx]);
                if (! (yysize <= yysize1
                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                  return 2;
                yysize = yysize1;
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  yysize1 = yysize + yystrlen (yyformat);
  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
    return 2;
  yysize = yysize1;

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, YYLTYPE *yylocationp, AmpAcScanner* scanner)
#else
static void
yydestruct (yymsg, yytype, yyvaluep, yylocationp, scanner)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
    YYLTYPE *yylocationp;
    AmpAcScanner* scanner;
#endif
{
  YYUSE (yyvaluep);
  YYUSE (yylocationp);
  YYUSE (scanner);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  switch (yytype)
    {

      default:
	break;
    }
}


struct yypstate
  {
    /* Number of syntax errors so far.  */
    int yynerrs;

    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       `yyss': related to states.
       `yyvs': related to semantic values.
       `yyls': related to locations.

       Refer to the stacks thru separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    /* The location stack.  */
    YYLTYPE yylsa[YYINITDEPTH];
    YYLTYPE *yyls;
    YYLTYPE *yylsp;

    /* The locations where the error started and ended.  */
    YYLTYPE yyerror_range[3];

    YYSIZE_T yystacksize;
    /* Used to determine if this is the first time this instance has
       been used.  */
    int yynew;
  };

/* Initialize the parser data structure.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
yypstate *
yypstate_new (void)
#else
yypstate *
yypstate_new ()

#endif
{
  yypstate *yyps;
  yyps = (yypstate *) malloc (sizeof *yyps);
  if (!yyps)
    return 0;
  yyps->yynew = 1;
  return yyps;
}

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void
yypstate_delete (yypstate *yyps)
#else
void
yypstate_delete (yyps)
    yypstate *yyps;
#endif
{
#ifndef yyoverflow
  /* If the stack was reallocated but the parse did not complete, then the
     stack still needs to be freed.  */
  if (!yyps->yynew && yyps->yyss != yyps->yyssa)
    YYSTACK_FREE (yyps->yyss);
#endif
  free (yyps);
}

#define amp_ac_yynerrs yyps->amp_ac_yynerrs
#define yystate yyps->yystate
#define yyerrstatus yyps->yyerrstatus
#define yyssa yyps->yyssa
#define yyss yyps->yyss
#define yyssp yyps->yyssp
#define yyvsa yyps->yyvsa
#define yyvs yyps->yyvs
#define yyvsp yyps->yyvsp
#define yylsa yyps->yylsa
#define yyls yyps->yyls
#define yylsp yyps->yylsp
#define yyerror_range yyps->yyerror_range
#define yystacksize yyps->yystacksize


/*---------------.
| yypush_parse.  |
`---------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAcScanner* scanner)
#else
int
yypush_parse (yyps, yypushed_char, yypushed_val, yypushed_loc, scanner)
    yypstate *yyps;
    int yypushed_char;
    YYSTYPE const *yypushed_val;
    YYLTYPE const *yypushed_loc;
    AmpAcScanner* scanner;
#endif
{
/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Location data for the lookahead symbol.  */
YYLTYPE yylloc;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;
  YYLTYPE yyloc;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N), yylsp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  if (!yyps->yynew)
    {
      yyn = yypact[yystate];
      goto yyread_pushed_token;
    }

  yytoken = 0;
  yyss = yyssa;
  yyvs = yyvsa;
  yyls = yylsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */
  yyssp = yyss;
  yyvsp = yyvs;
  yylsp = yyls;

#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
  /* Initialize the default location before parsing starts.  */
  yylloc.first_line   = yylloc.last_line   = 1;
  yylloc.first_column = yylloc.last_column = 1;
#endif

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;
	YYLTYPE *yyls1 = yyls;

	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),
		    &yyls1, yysize * sizeof (*yylsp),
		    &yystacksize);

	yyls = yyls1;
	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss_alloc, yyss);
	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
	YYSTACK_RELOCATE (yyls_alloc, yyls);
#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;
      yylsp = yyls + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      if (!yyps->yynew)
        {
          YYDPRINTF ((stderr, "Return for a new token:\n"));
          yyresult = YYPUSH_MORE;
          goto yypushreturn;
        }
      yyps->yynew = 0;
yyread_pushed_token:
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yypushed_char;
      if (yypushed_val)
        yylval = *yypushed_val;
      if (yypushed_loc)
        yylloc = *yypushed_loc;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  *++yyvsp = yylval;
  *++yylsp = yylloc;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];

  /* Default location.  */
  YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 28:

/* Line 1806 of yacc.c  */
#line 222 "ac-parser.y"
    {
		anjuta_token_set_type ((yyvsp[(2) - (2)]), ANJUTA_TOKEN_LAST);
	}
    break;

  case 30:

/* Line 1806 of yacc.c  */
#line 229 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (2)]), ANJUTA_TOKEN_NEXT);
    }
    break;

  case 31:

/* Line 1806 of yacc.c  */
#line 232 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(2) - (3)]), ANJUTA_TOKEN_NEXT);
    }
    break;

  case 34:

/* Line 1806 of yacc.c  */
#line 243 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (1)]), ANJUTA_TOKEN_OPERATOR);
    }
    break;

  case 35:

/* Line 1806 of yacc.c  */
#line 249 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
    }
    break;

  case 36:

/* Line 1806 of yacc.c  */
#line 253 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 37:

/* Line 1806 of yacc.c  */
#line 262 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_COMMENT, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (3)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (3)]));
		anjuta_token_merge ((yyval), (yyvsp[(3) - (3)]));
	}
    break;

  case 38:

/* Line 1806 of yacc.c  */
#line 272 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (AC_TOKEN_PKG_CHECK_MODULES, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
        amp_ac_scanner_load_module (scanner, (yyvsp[(2) - (2)]));
    }
    break;

  case 39:

/* Line 1806 of yacc.c  */
#line 286 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (amp_ac_autoconf_macro ((yyvsp[(1) - (2)])), NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
	}
    break;

  case 40:

/* Line 1806 of yacc.c  */
#line 294 "ac-parser.y"
    {
		anjuta_token_set_type ((yyvsp[(1) - (1)]), amp_ac_autoconf_macro ((yyvsp[(1) - (1)])));
	}
    break;

  case 41:

/* Line 1806 of yacc.c  */
#line 299 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (AC_TOKEN_AC_INIT, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
        amp_ac_scanner_load_properties (scanner, (yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 42:

/* Line 1806 of yacc.c  */
#line 307 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (1)]), AC_TOKEN_AC_OUTPUT);
    }
    break;

  case 43:

/* Line 1806 of yacc.c  */
#line 313 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (AC_TOKEN_OBSOLETE_AC_OUTPUT, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
        amp_ac_scanner_load_config (scanner, (yyvsp[(2) - (2)]));
    }
    break;

  case 44:

/* Line 1806 of yacc.c  */
#line 322 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (AC_TOKEN_AC_CONFIG_FILES, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
        amp_ac_scanner_load_config (scanner, (yyvsp[(2) - (2)]));
    }
    break;

  case 45:

/* Line 1806 of yacc.c  */
#line 334 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LAST, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(2) - (2)]));
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyval));
        (yyval) = (yyvsp[(1) - (2)]);
    }
    break;

  case 46:

/* Line 1806 of yacc.c  */
#line 340 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LAST, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(3) - (3)]));
		anjuta_token_merge ((yyvsp[(2) - (3)]), (yyval));
		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
        anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_START);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (3)]));
		anjuta_token_merge_children ((yyval), (yyvsp[(2) - (3)]));
    }
    break;

  case 47:

/* Line 1806 of yacc.c  */
#line 352 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
        //fprintf(stdout, "arg_list_body arg\n");
        //anjuta_token_dump ($1);
    }
    break;

  case 48:

/* Line 1806 of yacc.c  */
#line 358 "ac-parser.y"
    {
        //fprintf(stdout, "arg_list_body body\n");
        //anjuta_token_dump ($1);
        //fprintf(stdout, "arg_list_body separator\n");
        //anjuta_token_dump ($2);
        //fprintf(stdout, "arg_list_body arg\n");
        //anjuta_token_dump ($3);
        anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(2) - (3)]));
        anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(3) - (3)]));
        //fprintf(stdout, "arg_list_body merge\n");
        //anjuta_token_dump ($1);
    }
    break;

  case 49:

/* Line 1806 of yacc.c  */
#line 373 "ac-parser.y"
    {
		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_COMMENT, NULL);
		anjuta_token_merge ((yyval), (yyvsp[(1) - (3)]));
		anjuta_token_merge ((yyval), (yyvsp[(2) - (3)]));
		anjuta_token_merge ((yyval), (yyvsp[(3) - (3)]));
	}
    break;

  case 50:

/* Line 1806 of yacc.c  */
#line 382 "ac-parser.y"
    {
    	(yyval) = NULL;
    }
    break;

  case 51:

/* Line 1806 of yacc.c  */
#line 385 "ac-parser.y"
    {
    	(yyval) = (yyvsp[(2) - (2)]);
    }
    break;

  case 52:

/* Line 1806 of yacc.c  */
#line 392 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_OPEN_QUOTE);
        anjuta_token_set_type ((yyvsp[(3) - (3)]), ANJUTA_TOKEN_CLOSE_QUOTE);
        (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
        anjuta_token_merge ((yyvsp[(2) - (3)]), (yyvsp[(3) - (3)]));
    }
    break;

  case 53:

/* Line 1806 of yacc.c  */
#line 401 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_STRING, NULL);
    }
    break;

  case 54:

/* Line 1806 of yacc.c  */
#line 404 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 55:

/* Line 1806 of yacc.c  */
#line 407 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 56:

/* Line 1806 of yacc.c  */
#line 413 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_OPEN_QUOTE);
        anjuta_token_set_type ((yyvsp[(3) - (3)]), ANJUTA_TOKEN_CLOSE_QUOTE);
        (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
        anjuta_token_merge ((yyvsp[(2) - (3)]), (yyvsp[(3) - (3)]));
    }
    break;

  case 57:

/* Line 1806 of yacc.c  */
#line 422 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_STRING, NULL);
    }
    break;

  case 58:

/* Line 1806 of yacc.c  */
#line 425 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 59:

/* Line 1806 of yacc.c  */
#line 428 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 60:

/* Line 1806 of yacc.c  */
#line 434 "ac-parser.y"
    {
        anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_OPEN_QUOTE);
        anjuta_token_set_type ((yyvsp[(3) - (3)]), ANJUTA_TOKEN_CLOSE_QUOTE);
        (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
        anjuta_token_merge ((yyvsp[(2) - (3)]), (yyvsp[(3) - (3)]));
    }
    break;

  case 61:

/* Line 1806 of yacc.c  */
#line 443 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_STRING, NULL);
    }
    break;

  case 62:

/* Line 1806 of yacc.c  */
#line 446 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 63:

/* Line 1806 of yacc.c  */
#line 449 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 64:

/* Line 1806 of yacc.c  */
#line 452 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 65:

/* Line 1806 of yacc.c  */
#line 455 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 66:

/* Line 1806 of yacc.c  */
#line 458 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 67:

/* Line 1806 of yacc.c  */
#line 461 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 68:

/* Line 1806 of yacc.c  */
#line 464 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 69:

/* Line 1806 of yacc.c  */
#line 467 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 70:

/* Line 1806 of yacc.c  */
#line 470 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 71:

/* Line 1806 of yacc.c  */
#line 473 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 72:

/* Line 1806 of yacc.c  */
#line 476 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 74:

/* Line 1806 of yacc.c  */
#line 480 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 75:

/* Line 1806 of yacc.c  */
#line 489 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ITEM, NULL);
    }
    break;

  case 76:

/* Line 1806 of yacc.c  */
#line 492 "ac-parser.y"
    {
        //fprintf(stdout, "arg part\n");
        //anjuta_token_dump ($1);
        //fprintf(stdout, "arg body\n");
        //anjuta_token_dump ($2);
        anjuta_token_merge_children ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
        //fprintf(stdout, "arg merge\n");
        //anjuta_token_dump ($1);
    }
    break;

  case 77:

/* Line 1806 of yacc.c  */
#line 504 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ITEM, NULL);
    }
    break;

  case 78:

/* Line 1806 of yacc.c  */
#line 507 "ac-parser.y"
    {
        anjuta_token_merge_children ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 79:

/* Line 1806 of yacc.c  */
#line 513 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ITEM, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
    }
    break;

  case 84:

/* Line 1806 of yacc.c  */
#line 524 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ITEM, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
    }
    break;

  case 92:

/* Line 1806 of yacc.c  */
#line 541 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NEXT, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
    }
    break;

  case 93:

/* Line 1806 of yacc.c  */
#line 545 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NEXT, NULL);
        //fprintf(stdout, "separator spaces\n");
        //anjuta_token_dump ($2);
        //fprintf(stdout, "separator comma\n");
        //anjuta_token_dump ($1);
        //fprintf(stdout, "separator next\n");
        //anjuta_token_dump ($$);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (2)]));
        anjuta_token_merge_children ((yyval), (yyvsp[(2) - (2)]));
        //fprintf(stdout, "separator merge\n");
        //anjuta_token_dump ($$);
    }
    break;

  case 94:

/* Line 1806 of yacc.c  */
#line 561 "ac-parser.y"
    {
        (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
        anjuta_token_merge ((yyvsp[(2) - (3)]), (yyvsp[(3) - (3)]));
    }
    break;

  case 95:

/* Line 1806 of yacc.c  */
#line 568 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_STRING, NULL);
    }
    break;

  case 96:

/* Line 1806 of yacc.c  */
#line 571 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 98:

/* Line 1806 of yacc.c  */
#line 575 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 99:

/* Line 1806 of yacc.c  */
#line 578 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 100:

/* Line 1806 of yacc.c  */
#line 581 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 101:

/* Line 1806 of yacc.c  */
#line 584 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 102:

/* Line 1806 of yacc.c  */
#line 587 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 103:

/* Line 1806 of yacc.c  */
#line 590 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 104:

/* Line 1806 of yacc.c  */
#line 593 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 106:

/* Line 1806 of yacc.c  */
#line 597 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 107:

/* Line 1806 of yacc.c  */
#line 600 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
    }
    break;

  case 108:

/* Line 1806 of yacc.c  */
#line 606 "ac-parser.y"
    {
        (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
        anjuta_token_merge ((yyval), (yyvsp[(1) - (1)]));
    }
    break;

  case 109:

/* Line 1806 of yacc.c  */
#line 610 "ac-parser.y"
    {
        anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
	}
    break;

  case 124:

/* Line 1806 of yacc.c  */
#line 639 "ac-parser.y"
    {
		anjuta_token_set_type ((yyvsp[(1) - (1)]), ANJUTA_TOKEN_EOL);
	}
    break;



/* Line 1806 of yacc.c  */
#line 2732 "ac-parser.c"
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;
  *++yylsp = yyloc;

  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (&yylloc, scanner, YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (&yylloc, scanner, yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }

  yyerror_range[1] = yylloc;

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval, &yylloc, scanner);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  yyerror_range[1] = yylsp[1-yylen];
  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      yyerror_range[1] = *yylsp;
      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp, yylsp, scanner);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  *++yyvsp = yylval;

  yyerror_range[2] = yylloc;
  /* Using YYLLOC is tempting, but would change the location of
     the lookahead.  YYLOC is available though.  */
  YYLLOC_DEFAULT (yyloc, yyerror_range, 2);
  *++yylsp = yyloc;

  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined(yyoverflow) || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (&yylloc, scanner, YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, &yylloc, scanner);
    }
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp, yylsp, scanner);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  yyps->yynew = 1;

yypushreturn:
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}



/* Line 2067 of yacc.c  */
#line 730 "ac-parser.y"


